@@ -25,7 +25,6 @@ if TYPE_CHECKING:
 class _CertificateInfoCliConnector(
     ScanCommandCliConnector["CertificateInfoScanResult", "CertificateInfoExtraArgument"]
 ):
-
     _cli_option = "certinfo"
     _cli_description = "Retrieve and analyze a server's certificate(s) to verify its validity."
 
@@ -76,37 +75,55 @@ class _CertificateInfoCliConnector(
         server_name_indication = result.hostname_used_for_server_name_indication
         result_as_txt.append(cls._format_field("Hostname sent for SNI:", server_name_indication))
 
+        # Display a summary of the certificate deployments
+        all_leaf_public_key_names = []
+        for cert_deployment in result.certificate_deployments:
+            leaf_certificate = cert_deployment.received_certificate_chain[0]
+            all_leaf_public_key_names.append(leaf_certificate.public_key().__class__.__name__)
+
+        leaf_certs_description = str(len(result.certificate_deployments))
+        leaf_certs_description += " (" + ", ".join(all_leaf_public_key_names) + ")"
+
+        result_as_txt.append(cls._format_field("Number of cert chains detected:", leaf_certs_description))
+        no_sni_cert_txt = "Yes" if result.certificate_deployment_with_sni_disabled else "No"
+        result_as_txt.append(cls._format_field("Cert chain with SNI disabled:", no_sni_cert_txt))
+
         # Display each certificate deployment
-        result_as_txt.append(
-            cls._format_field("Number of certificates detected:", str(len(result.certificate_deployments)))
-        )
         for index, cert_deployment in enumerate(result.certificate_deployments):
             result_as_txt.append("\n")
-            result_as_txt.extend(cls._cert_deployment_to_console_output(index, cert_deployment))
+            result_as_txt.extend(
+                cls._cert_deployment_to_console_output(index + 1, cert_deployment, was_sni_disabled=False)
+            )
+
+        # Display the non-SNI certificate deployment if present
+        if result.certificate_deployment_with_sni_disabled:
+            result_as_txt.append("")
+            result_as_txt.extend(
+                cls._cert_deployment_to_console_output(
+                    None, result.certificate_deployment_with_sni_disabled, was_sni_disabled=True
+                )
+            )
 
         return result_as_txt
 
     @classmethod
     def _cert_deployment_to_console_output(
-        cls, index: int, cert_deployment: CertificateDeploymentAnalysisResult
+        cls, index: Optional[int], cert_deployment: CertificateDeploymentAnalysisResult, was_sni_disabled: bool
     ) -> List[str]:
         leaf_certificate = cert_deployment.received_certificate_chain[0]
-        deployment_as_txt = [
-            cls._format_subtitle(f"Certificate #{index} ( {leaf_certificate.public_key().__class__.__name__} )")
-        ]
+        if was_sni_disabled:
+            deployment_as_txt = [cls._format_subtitle("Certificate Chain with SNI disabled - can be ignored")]
+        else:
+            deployment_as_txt = [
+                cls._format_subtitle(
+                    f"Certificate Chain #{index} ({leaf_certificate.public_key().__class__.__name__}, SNI enabled)"
+                )
+            ]
 
         deployment_as_txt.extend(cls._get_basic_certificate_text(leaf_certificate))
 
         # Trust section
-        deployment_as_txt.append("")
-        deployment_as_txt.append(cls._format_subtitle(f"Certificate #{index} - Trust"))
-
-        hostname_validation_text = (
-            "OK - Certificate matches server hostname"
-            if cert_deployment.leaf_certificate_subject_matches_hostname
-            else "FAILED - Certificate does NOT match server hostname"
-        )
-        deployment_as_txt.append(cls._format_field("Hostname Validation:", hostname_validation_text))
+        deployment_as_txt.append(cls._format_subtitle("Trust"))
 
         # Path validation that was successfully tested
         for path_result in cert_deployment.path_validation_results:
@@ -118,7 +135,7 @@ class _CertificateInfoCliConnector(
                 path_txt = f"OK - Certificate is trusted{ev_txt}"
 
             else:
-                path_txt = f"FAILED - Certificate is NOT Trusted: {path_result.openssl_error_string}"
+                path_txt = f"FAILED - Certificate is NOT Trusted: {path_result.validation_error}"
 
             deployment_as_txt.append(
                 cls._format_field(
@@ -183,7 +200,7 @@ class _CertificateInfoCliConnector(
         deployment_as_txt.append(cls._format_field("Verified Chain contains SHA1:", sha1_text))
 
         # Extensions section
-        deployment_as_txt.extend(["", cls._format_subtitle(f"Certificate #{index} - Extensions")])
+        deployment_as_txt.append(cls._format_subtitle("Certificate Extensions"))
 
         # OCSP must-staple
         must_staple_txt = (
@@ -206,7 +223,7 @@ class _CertificateInfoCliConnector(
         deployment_as_txt.append(cls._format_field("Certificate Transparency:", sct_txt))
 
         # OCSP stapling
-        deployment_as_txt.extend(["", cls._format_subtitle(f"Certificate #{index} - OCSP Stapling")])
+        deployment_as_txt.append(cls._format_subtitle("OCSP Stapling"))
 
         if cert_deployment.ocsp_response is None:
             deployment_as_txt.append(cls._format_field("", "NOT SUPPORTED - Server did not send back an OCSP response"))
@@ -251,16 +268,16 @@ class _CertificateInfoCliConnector(
                             cls._format_field("Cert Status:", cert_deployment.ocsp_response.certificate_status.name),
                             cls._format_field("Cert Serial Number:", str(cert_deployment.ocsp_response.serial_number)),
                             cls._format_field(
-                                "This Update:", cert_deployment.ocsp_response.this_update.date().isoformat()
+                                "This Update:", cert_deployment.ocsp_response.this_update_utc.date().isoformat()
                             ),
                         ]
                     )
 
                     # The Next Update field is optional: https://github.com/nabla-c0d3/sslyze/issues/481
-                    if cert_deployment.ocsp_response.next_update is None:
+                    if cert_deployment.ocsp_response.next_update_utc is None:
                         next_update_str = "None"
                     else:
-                        next_update_str = cert_deployment.ocsp_response.next_update.date().isoformat()
+                        next_update_str = cert_deployment.ocsp_response.next_update_utc.date().isoformat()
                     ocsp_resp_txt.append(cls._format_field("Next Update:", next_update_str))
 
             deployment_as_txt.extend(ocsp_resp_txt)
@@ -277,8 +294,8 @@ class _CertificateInfoCliConnector(
             cls._format_field("Common Name:", _get_subject_as_short_text(certificate)),
             cls._format_field("Issuer:", _get_issuer_as_short_text(certificate)),
             cls._format_field("Serial Number:", str(certificate.serial_number)),
-            cls._format_field("Not Before:", certificate.not_valid_before.date().isoformat()),
-            cls._format_field("Not After:", certificate.not_valid_after.date().isoformat()),
+            cls._format_field("Not Before:", certificate.not_valid_before_utc.date().isoformat()),
+            cls._format_field("Not After:", certificate.not_valid_after_utc.date().isoformat()),
             cls._format_field("Public Key Algorithm:", certificate.public_key().__class__.__name__),
         ]
 
