@@ -6,7 +6,9 @@ from nassl.ssl_client import ClientCertificateRequested
 
 from sslyze.server_connectivity import ServerConnectivityInfo, TlsVersionEnum
 
-ArgumentsToGetCertificateChain = Tuple[ServerConnectivityInfo, Optional[Path], Optional[TlsVersionEnum], Optional[str]]
+ArgumentsToGetCertificateChain = Tuple[
+    ServerConnectivityInfo, Optional[Path], Optional[TlsVersionEnum], Optional[str], bool
+]
 
 
 def get_certificate_chain(
@@ -14,8 +16,11 @@ def get_certificate_chain(
     custom_ca_file: Optional[Path],
     tls_version: Optional[TlsVersionEnum],
     openssl_cipher_string: Optional[str],
-) -> Tuple[List[str], Optional[nassl._nassl.OCSP_RESPONSE], Optional[Path]]:
-    ssl_connection = server_info.get_preconfigured_tls_connection(override_tls_version=tls_version)
+    should_enable_sni: bool,
+) -> Tuple[List[str], Optional[nassl._nassl.OCSP_RESPONSE], Optional[Path], bool]:
+    ssl_connection = server_info.get_preconfigured_tls_connection(
+        override_tls_version=tls_version, should_enable_server_name_indication=should_enable_sni
+    )
     if openssl_cipher_string:
         ssl_connection.ssl_client.set_cipher_list(openssl_cipher_string)
 
@@ -34,4 +39,4 @@ def get_certificate_chain(
     finally:
         ssl_connection.close()
 
-    return received_chain_as_pem, ocsp_response, custom_ca_file
+    return received_chain_as_pem, ocsp_response, custom_ca_file, should_enable_sni
