@@ -4,12 +4,13 @@ from http.client import HTTPResponse
 from dataclasses import dataclass, asdict
 from traceback import TracebackException
 from urllib.parse import urlsplit
+from pydantic import BaseModel, model_validator
 
-import pydantic
 
 # TODO: Fix type annotations in nassl
 from nassl._nassl import SslError  # type: ignore
 
+from sslyze.json.pydantic_utils import BaseModelWithOrmMode
 from sslyze.json.scan_attempt_json import ScanCommandAttemptAsJson
 from sslyze.plugins.plugin_base import (
     ScanCommandImplementation,
@@ -23,27 +24,11 @@ from sslyze.plugins.plugin_base import (
 from sslyze.server_connectivity import ServerConnectivityInfo
 from sslyze.connection_helpers.http_request_generator import HttpRequestGenerator
 from sslyze.connection_helpers.http_response_parser import HttpResponseParser, NotAValidHttpResponseError
-from typing import List, Optional
-
+from typing import List, Optional, Any
 
 _logger = logging.getLogger(__name__)
 
 
-@dataclass(frozen=True)
-class ExpectCtHeader:
-    """An Expect-CT header parsed from a server's HTTP response.
-
-    Attributes:
-        max-age: The content of the max-age field.
-        report-uri: The content of report-uri field.
-        enforce: True if enforce directive is set.
-    """
-
-    max_age: Optional[int]
-    report_uri: Optional[str]
-    enforce: bool
-
-
 @dataclass(frozen=True)
 class StrictTransportSecurityHeader:
     """A Strict-Transport-Security header parsed from a server's HTTP response.
@@ -72,8 +57,6 @@ class HttpHeadersScanResult(ScanCommandResult):
             all the subsequent fields will be ``None`` as SSLyze did not receive a valid HTTP response from the server.
         http_path_redirected_to: The path SSLyze was eventually redirected to after sending the initial HTTP request.
         strict_transport_security_header: The Strict-Transport-Security header returned by the server.
-        expect_ct_header: DEPRECATED - will always be ``None``. This is because the Expect-CT header has officially
-            been deprecated.
     """
 
     http_request_sent: str
@@ -81,31 +64,32 @@ class HttpHeadersScanResult(ScanCommandResult):
 
     http_path_redirected_to: Optional[str]
     strict_transport_security_header: Optional[StrictTransportSecurityHeader]
-    expect_ct_header: None = None  # TODO(6.0.0): Remove as this is a deprecated field
 
 
-class _StrictTransportSecurityHeaderAsJson(pydantic.BaseModel):
+class _StrictTransportSecurityHeaderAsJson(BaseModel):
     max_age: Optional[int]
     preload: bool
     include_subdomains: bool
 
 
-_StrictTransportSecurityHeaderAsJson.__doc__ = StrictTransportSecurityHeader.__doc__  # type: ignore
+assert StrictTransportSecurityHeader.__doc__
+_StrictTransportSecurityHeaderAsJson.__doc__ = StrictTransportSecurityHeader.__doc__
 
 
-class HttpHeadersScanResultAsJson(pydantic.BaseModel):
+class HttpHeadersScanResultAsJson(BaseModelWithOrmMode):
     http_request_sent: str
     http_error_trace: Optional[str]
 
     http_path_redirected_to: Optional[str]
     strict_transport_security_header: Optional[_StrictTransportSecurityHeaderAsJson]
-    expect_ct_header: None = None  # TODO(6.0.0): Remove as this is a deprecated field
-
-    class Config:
-        orm_mode = True
 
+    @model_validator(mode="before")
     @classmethod
-    def from_orm(cls, result: HttpHeadersScanResult) -> "HttpHeadersScanResultAsJson":
+    def _handle_object(cls, data: Any) -> Any:
+        if not isinstance(data, HttpHeadersScanResult):
+            return data
+
+        result: HttpHeadersScanResult = data
         http_error_trace_as_str = None
         if result.http_error_trace:
             http_error_trace_as_str = ""
@@ -116,7 +100,7 @@ class HttpHeadersScanResultAsJson(pydantic.BaseModel):
         if result.strict_transport_security_header:
             sts_header_json = _StrictTransportSecurityHeaderAsJson(**asdict(result.strict_transport_security_header))
 
-        return cls(
+        return dict(
             http_request_sent=result.http_request_sent,
             http_error_trace=http_error_trace_as_str,
             http_path_redirected_to=result.http_path_redirected_to,
@@ -124,7 +108,8 @@ class HttpHeadersScanResultAsJson(pydantic.BaseModel):
         )
 
 
-HttpHeadersScanResultAsJson.__doc__ = HttpHeadersScanResult.__doc__  # type: ignore
+assert HttpHeadersScanResult.__doc__
+HttpHeadersScanResultAsJson.__doc__ = HttpHeadersScanResult.__doc__
 
 
 class HttpHeadersScanAttemptAsJson(ScanCommandAttemptAsJson):
@@ -132,7 +117,6 @@ class HttpHeadersScanAttemptAsJson(ScanCommandAttemptAsJson):
 
 
 class _HttpHeadersCliConnector(ScanCommandCliConnector[HttpHeadersScanResult, None]):
-
     _cli_option = "http_headers"
     _cli_description = "Test a server for the presence of security-related HTTP headers."
 
@@ -216,7 +200,9 @@ def _retrieve_and_analyze_http_response(server_info: ServerConnectivityInfo) ->
             # Send an HTTP GET request to the server
             ssl_connection.ssl_client.write(
                 HttpRequestGenerator.get_request(
-                    host=server_info.network_configuration.tls_server_name_indication, path=next_location_path
+                    host=server_info.network_configuration.tls_server_name_indication,
+                    path=next_location_path,
+                    user_agent=server_info.network_configuration.http_user_agent,
                 )
             )
             http_response = HttpResponseParser.parse_from_ssl_connection(ssl_connection.ssl_client)
@@ -241,7 +227,9 @@ def _retrieve_and_analyze_http_response(server_info: ServerConnectivityInfo) ->
 
     # Prepare the results
     initial_http_request = HttpRequestGenerator.get_request(
-        host=server_info.network_configuration.tls_server_name_indication, path="/"
+        host=server_info.network_configuration.tls_server_name_indication,
+        path="/",
+        user_agent=server_info.network_configuration.http_user_agent,
     ).decode("ascii")
 
     if http_error_trace:
