@@ -1,6 +1,10 @@
 from nassl.ssl_client import ClientCertificateRequested
 
-from sslyze.plugins.fallback_scsv_plugin import FallbackScsvScanResult, FallbackScsvImplementation
+from sslyze.plugins.fallback_scsv_plugin import (
+    FallbackScsvScanResult,
+    FallbackScsvImplementation,
+    FallbackScsvScanResultAsJson,
+)
 
 from sslyze.server_setting import (
     ServerNetworkLocation,
@@ -14,7 +18,7 @@ import pytest
 
 
 class TestFallbackScsvPlugin:
-    def test_fallback_good(self):
+    def test_fallback_good(self) -> None:
         # Given a server that supports SCSV
         server_location = ServerNetworkLocation("www.google.com", 443)
         server_info = check_connectivity_to_server_and_return_info(server_location)
@@ -28,8 +32,12 @@ class TestFallbackScsvPlugin:
         # And a CLI output can be generated
         assert FallbackScsvImplementation.cli_connector_cls.result_to_console_output(result)
 
+        # And the result can be converted to JSON
+        result_as_json = FallbackScsvScanResultAsJson.model_validate(result).model_dump_json()
+        assert result_as_json
+
     @can_only_run_on_linux_64
-    def test_fallback_bad(self):
+    def test_fallback_bad(self) -> None:
         # Given a server that does NOT support SCSV
         with LegacyOpenSslServer() as server:
             server_location = ServerNetworkLocation(
@@ -44,7 +52,7 @@ class TestFallbackScsvPlugin:
         assert not result.supports_fallback_scsv
 
     @can_only_run_on_linux_64
-    def test_fails_when_client_auth_failed(self):
+    def test_fails_when_client_auth_failed(self) -> None:
         # Given a server that does NOT support SCSV and that requires client authentication
         with LegacyOpenSslServer(client_auth_config=ClientAuthConfigEnum.REQUIRED) as server:
             # And sslyze does NOT provide a client certificate
@@ -58,7 +66,7 @@ class TestFallbackScsvPlugin:
                 FallbackScsvImplementation.scan_server(server_info)
 
     @can_only_run_on_linux_64
-    def test_works_when_client_auth_succeeded(self):
+    def test_works_when_client_auth_succeeded(self) -> None:
         # Given a server that does NOT support SCSV and that requires client authentication
         with LegacyOpenSslServer(client_auth_config=ClientAuthConfigEnum.REQUIRED) as server:
             server_location = ServerNetworkLocation(
