@@ -41,8 +41,8 @@ class TestOpportunisticTls:
         assert tls_probing_result.cipher_suite_supported
 
         # And the result can be converted to JSON
-        tls_probing_result_as_json = _ServerTlsProbingResultAsJson.from_orm(tls_probing_result)
-        assert tls_probing_result_as_json.json()
+        tls_probing_result_as_json = _ServerTlsProbingResultAsJson.model_validate(tls_probing_result)
+        assert tls_probing_result_as_json.model_dump_json()
 
     def test_xmpp_but_server_rejected_opportunistic_tls(self):
         # Given an XMPP server
